@@ -11,18 +11,29 @@ from mpl_toolkits import mplot3d
 from matplotlib.lines import Line2D
 get_ipython().run_line_magic('matplotlib', 'inline')
 from collections import defaultdict
+import pkg_resources
 import os.path as op
 
 # ### Defining a Global Variables (Location and Constants)
 
 # In[3]:
-mineralPath = op.dirname(op.abspath(__file__)) + '\\resources\\mineralDictionary.txt'
-gasPath = op.dirname(op.abspath(__file__)) + '\\resources\\gasLst.txt'
-aqPath = op.dirname(op.abspath(__file__)) + '\\resources\\aqueousLst.txt'
-diePath =  op.dirname(op.abspath(__file__)) + '\\resources\\dielectric.csv'
-inpPath =  op.dirname(op.abspath(__file__)) + '\\resources\\input.csv'
-denPath =  op.dirname(op.abspath(__file__)) + '\\resources\\Wat_den.csv'
-gPath =  op.dirname(op.abspath(__file__)) + '\\resources\\water_gibbs.csv'
+resource_package = 'DEWPython'
+min_path = '/'.join(('resources', 'mineralDictionary.txt'))
+mineralPath = pkg_resources.resource_filename(resource_package, min_path)
+gas_path = '/'.join(('resources', 'gasLst.txt'))
+gasPath = pkg_resources.resource_filename(resource_package, gas_path)
+aq_path = '/'.join(('resources', 'aqueousLst.txt'))
+aqPath = pkg_resources.resource_filename(resource_package, aq_path)
+die_path =  '/'.join(('resources', 'dielectric.csv'))
+diePath = pkg_resources.resource_filename(resource_package, die_path)
+inp_path ='/'.join(('resources', 'input.csv'))
+inpPath = pkg_resources.resource_filename(resource_package, inp_path)
+den_path ='/'.join(('resources', 'input.csv'))
+denPath = pkg_resources.resource_filename(resource_package, den_path)
+g_path = '/'.join(('resources', 'water_gibbs.csv'))
+gPath = pkg_resources.resource_filename(resource_package, g_path)
+sup_path = '/'.join(('resources', 'SUPCRTBL.exe'))
+supPath =  pkg_resources.resource_filename(resource_package, sup_path)
 
 global Tr, bigQ, Chi, Pr, E_PrTr, bigR, Psi, Theta, Upsilon, Conversion, mineralDictionary
 bigQ = 5.903E-07
@@ -218,7 +229,11 @@ class DEWEquations:
             D = 0.0170609505 - 0.0146355822 /  ( Tr * Tr )  + 0.0579768283 /  ( Tr * Tr * Tr )
             E = - 0.000841246372 + 0.00495186474 /  ( Tr * Tr )  - 0.00916248538 /  ( Tr * Tr * Tr )
             f = - 0.100358152 / Tr
+            #####
+            # This value has been edited to be consistent with Mark Ghiorso's objective-C version of DEW and the original Zhang and Duan 2005 paper, 
+            # although it is incosistent with the Excel-implemented DEW Model
             g = np.double(- 0.00182674744 * Tr)
+            ########
             delta = 1 + B / Vr + C /  ( Vr * Vr )  + D / pow(Vr, 4) + E / pow(Vr, 5) +  ( f /  ( Vr * Vr )  + g / pow(Vr, 4) )  * np.exp(- 0.0105999998 / pow(Vr, 2))
             kappa = B * cc + 2 * C *  ( cc * cc )  * density + 4 * D * pow(cc, 4) * pow(density, 3) + 5 * E * pow(cc, 5) * pow(density, 4) +  ( 2 * f *  ( cc * cc )  * density + 4 * g * pow(cc, 4) * pow(density, 3) -  ( f /  ( Vr * Vr )  + g / pow(Vr, 4) )  *  ( 2 * 0.0105999998 *  ( cc * cc )  * density ) )  * np.exp(- 0.0105999998 /  ( Vr * Vr ))
             fn_return_value = m /  ( ZD05_R * TK *  ( delta + density * kappa ) )
@@ -634,7 +649,7 @@ class DEWEquations:
             #This represents the pressure and temperature dependent solvent function
             g = DEWEquations.calculateG(P, T, density)
             #Defines the electrostatic radius at the input P and T
-            re = reref + (Z) * g
+            re = reref + np.abs(Z) * g
             fn_return_value = eta *  ( Z * Z / re - Z /  ( 3.082 + g ) )
         return fn_return_value
     
@@ -739,7 +754,7 @@ class DEWEquations:
                     dfdP = - ( pow(( T - 155 )  / 300, 4.8) + 36.66666 * pow(( T - 155 )  / 300, 16) )  *  ( 3 * - 1.504956E-10 * pow(1000 - P, 2) + 4 * 5.017997E-14 * pow(1000 - P, 3) )
                 else:
                     dfdP = 0
-                fn_return_value = - b_g * calculate_drhodP(density, T, equation) * g /  ( 1 - density )  - dfdP
+                fn_return_value = - b_g * DEWEquations.calculate_drhodP(density, T, equation) * g /  ( 1 - density )  - dfdP
         return fn_return_value
     
     def calculateQ(pressure, temperature, density, densityEquation, epsilonEquation, Psat):
